==> vokoscreen-ng_3.1.0.orig.tar.gz: vokoscreenNG-3.1.0/src/language/sr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="sr">
<context>
    <name>QvkAudioController</name>
    <message>
        <source>Select one or more devices</source>
        <translation>Означи један или више уређаја</translation>
    </message>
</context>
<context>
    <name>QvkCameraController</name>
    <message>
        <source>Camera</source>
        <translation>Kamera</translation>
    </message>
</context>
<context>
    <name>QvkCameraWindow</name>
    <message>
        <source>Switch to Window</source>
        <translation>Промени на прозор</translation>
    </message>
    <message>
        <source>Switch to Fullscreen</source>
        <translation>Промени на цео екран</translation>
    </message>
</context>
<context>
    <name>QvkDirectSoundController</name>
    <message>
        <source>Select one or more devices</source>
        <translation>Означи један или више уређаја</translation>
    </message>
</context>
<context>
    <name>QvkHelp</name>
    <message>
        <source>Help</source>
        <translation>Помоћ</translation>
    </message>
</context>
<context>
    <name>QvkImageFromTabs</name>
    <message>
        <source>No filemanager found.</source>
        <translation>Претраживач датотека није пронађен</translation>
    </message>
    <message>
        <source>Please install a filemanager.</source>
        <translation>Молим вас инсталирајте претраживач датотека</translation>
    </message>
</context>
<context>
    <name>QvkLimitDiskFreeSpace</name>
    <message>
        <source>Warning</source>
        <translation>Upozorenje</translation>
    </message>
    <message>
        <source>The recording is not started, not enough free disk space.</source>
        <translation>Снимање није почело, нема довољно слободног места на диску.</translation>
    </message>
    <message>
        <source>The free disk space limit is reached.</source>
        <translation>Досегнуто је ограничење слободног простора на диску.</translation>
    </message>
    <message>
        <source>Limit of free disk space</source>
        <translation>Граница слободног места на диску</translation>
    </message>
    <message>
        <source>Megabyte</source>
        <translation>Megabajt</translation>
    </message>
    <message>
        <source>The recording was stopped, not enough free disk space.</source>
        <translation>Снимање је заустављено, нема довољно слободног места на диску.</translation>
    </message>
</context>
<context>
    <name>QvkMainWindow</name>
    <message>
        <source>Fullscreen</source>
        <translation>Пун екран</translation>
    </message>
    <message>
        <source>Window</source>
        <translation>Прозор</translation>
    </message>
    <message>
        <source>No filemanager found.</source>
        <translation>Претраживач датотека није пронађен</translation>
    </message>
    <message>
        <source>Please install a filemanager.</source>
        <translation>Молим вас инсталирајте претраживач датотека</translation>
    </message>
    <message>
        <source>Sourcecode</source>
        <translation>Изворни код</translation>
    </message>
    <message>
        <source>Homepage</source>
        <translation>Почетна</translation>
    </message>
    <message>
        <source>Translations</source>
        <translation>Преводи</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>Донирај</translation>
    </message>
</context>
<context>
    <name>QvkPulseAudioWatcher</name>
    <message>
        <source>Select one or more devices</source>
        <translation>Означи један или више уређаја</translation>
    </message>
</context>
<context>
    <name>QvkRegionChoise</name>
    <message>
        <source>Area</source>
        <translation>Подручје</translation>
    </message>
</context>
<context>
    <name>QvkSystray</name>
    <message>
        <source>Start</source>
        <translation>Старт</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Стоп</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Пауза</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Настави</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Излаз</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Kamera</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>Увеличавање</translation>
    </message>
</context>
<context>
    <name>QvkSystrayAlternative</name>
    <message>
        <source>Start</source>
        <translation>Старт</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Стоп</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Пауза</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Настави</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Излаз</translation>
    </message>
</context>
<context>
    <name>cameraSettingsDialog</name>
    <message>
        <source>Dialog</source>
        <translation>Дијалог</translation>
    </message>
    <message>
        <source>Flip horizontal</source>
        <translation>Окрени хоризонтално</translation>
    </message>
    <message>
        <source>Flip vertical</source>
        <translation>Окрени вертикално</translation>
    </message>
    <message>
        <source>Invert</source>
        <translation>Изокрени</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>Сиво</translation>
    </message>
    <message>
        <source>Black-and-white</source>
        <translation>Црно-бело</translation>
    </message>
    <message>
        <source>Remove window frame</source>
        <translation>Уклони оквир прозора</translation>
    </message>
    <message>
        <source>160x120</source>
        <translation>160х120</translation>
    </message>
    <message>
        <source>320x240</source>
        <translation>320х240</translation>
    </message>
    <message>
        <source>Camera settings</source>
        <translation>Подешавања камере</translation>
    </message>
    <message>
        <source>640x480</source>
        <translation>640х480</translation>
    </message>
</context>
<context>
    <name>formMainWindow</name>
    <message>
        <source>Area</source>
        <translation>Подручје</translation>
    </message>
    <message>
        <source>Reset</source>
        <translation>Поново намести</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>Увеличавање</translation>
    </message>
    <message>
        <source>Countdown</source>
        <translation>Одбројавање</translation>
    </message>
    <message>
        <source>Video size:</source>
        <translation>Величина видеа</translation>
    </message>
    <message>
        <source>Free disk space:</source>
        <translation>Слободан простор на диску</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>Информације</translation>
    </message>
    <message>
        <source>Record Time:</source>
        <translation>Сними време:</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation>Аудио</translation>
    </message>
    <message>
        <source>Frames</source>
        <translation>Фрејмови</translation>
    </message>
    <message>
        <source>Videocodec</source>
        <translation>Видео кодек</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>Формат</translation>
    </message>
    <message>
        <source>Audiocodec</source>
        <translation>Аудио кодек</translation>
    </message>
    <message>
        <source>Quality</source>
        <translation>Квалитет</translation>
    </message>
    <message>
        <source>Do not record mouse cursor</source>
        <translation>Немој снимати стрелицу</translation>
    </message>
    <message>
        <source>Hour</source>
        <translation>Сат</translation>
    </message>
    <message>
        <source>Minute</source>
        <translation>Минут</translation>
    </message>
    <message>
        <source>Start the timer</source>
        <translation>Покрени тајмер</translation>
    </message>
    <message>
        <source>Stop recording after</source>
        <translation>Прекини снимање после</translation>
    </message>
    <message>
        <source>Hours</source>
        <translation>Сати</translation>
    </message>
    <message>
        <source>Minutes</source>
        <translation>Минути</translation>
    </message>
    <message>
        <source>Seconds</source>
        <translation>Секунде</translation>
    </message>
    <message>
        <source>Videopath</source>
        <translation>Видео пут</translation>
    </message>
    <message>
        <source>Limit of free disk space</source>
        <translation>Граница слободног места на диску</translation>
    </message>
    <message>
        <source>Show in systray</source>
        <translation>Прикажи у &apos;&apos;systray&apos;&apos;</translation>
    </message>
    <message>
        <source>Second wait before recording</source>
        <translation>Одлагање снимања у секундама</translation>
    </message>
    <message>
        <source>Look for updates</source>
        <translation>Потражи исправке</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Помоћ</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>Снимак</translation>
    </message>
    <message>
        <source>Available</source>
        <translation>Доступно</translation>
    </message>
    <message>
        <source>Not available</source>
        <translation>Није доступно</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Старт</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Стоп</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Пауза</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Настави</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Почни</translation>
    </message>
    <message>
        <source>Folder</source>
        <translation>Фасцикла</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Kamera</translation>
    </message>
    <message>
        <source>Invert</source>
        <translation>Изокрени</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>Сиво</translation>
    </message>
    <message>
        <source>Send Report</source>
        <translation>Пошаљи извештај</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F10</source>
        <translation>CTRL+SHIFT+F10</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F11</source>
        <translation>CTRL+SHIFT+F11</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F12</source>
        <translation>CTRL+SHIFT+F12</translation>
    </message>
    <message>
        <source>Play last record</source>
        <translation>Пусти задњи снимак</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Отвори директоријум</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F8</source>
        <translation>CTRL+SHIFT+F8</translation>
    </message>
    <message>
        <source>Minimized when recording starts</source>
        <translation>Vokoscreen минимизиран кад снимање почне</translation>
    </message>
    <message>
        <source>Starts minimized</source>
        <translation>Почни минимизован</translation>
    </message>
    <message>
        <source>Flip horizontal</source>
        <translation>Окрени хоризонтално</translation>
    </message>
    <message>
        <source>Flip vertical</source>
        <translation>Окрени вертикално</translation>
    </message>
    <message>
        <source>Black-and-white</source>
        <translation>Црно-бело</translation>
    </message>
    <message>
        <source>Remove window frame</source>
        <translation>Уклони оквир прозора</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>Донирај</translation>
    </message>
    <message>
        <source>Reset all settings at the next start</source>
        <translation>Врати све на фабричка подешавања када следећи пут снимање почне </translation>
    </message>
    <message>
        <source>Copyright and license from pictures</source>
        <translation>Ауторска права и лиценца од слика</translation>
    </message>
    <message>
        <source>Megabyte</source>
        <translation>Megabajt</translation>
    </message>
    <message>
        <source>Screencast</source>
        <translation>Пренос екрана</translation>
    </message>
    <message>
        <source>Player</source>
        <translation>Плејер</translation>
    </message>
    <message>
        <source>Log</source>
        <translation>Дневник</translation>
    </message>
</context>
<context>
    <name>license</name>
    <message>
        <source>Copyright and license from pictures</source>
        <translation>Ауторска права и лиценца од слика</translation>
    </message>
</context>
<context>
    <name>player</name>
    <message>
        <source>Play</source>
        <translation>Почни</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Пауза</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Стоп</translation>
    </message>
    <message>
        <source>Open File</source>
        <translation>Отвори документ</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Пун екран</translation>
    </message>
    <message>
        <source>Previous frame</source>
        <translation>Прошли кадар</translation>
    </message>
    <message>
        <source>Next frame</source>
        <translation>Следећи кадар</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>Нем</translation>
    </message>
    <message>
        <source>Move menu</source>
        <translation>Помери мени</translation>
    </message>
</context>
</TS>

==> vokoscreen-ng_3.3.0.orig.tar.gz: vokoscreenNG-3.3.0/src/language/sr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="sr">
<context>
    <name>QvkAudioController</name>
    <message>
        <source>Select one or more devices</source>
        <translation>Означи један или више уређаја</translation>
    </message>
</context>
<context>
    <name>QvkCameraController</name>
    <message>
        <source>Camera</source>
        <translation>Kamera</translation>
    </message>
</context>
<context>
    <name>QvkCameraWindow</name>
    <message>
        <source>Switch to Window</source>
        <translation>Промени на прозор</translation>
    </message>
    <message>
        <source>Switch to Fullscreen</source>
        <translation>Промени на цео екран</translation>
    </message>
</context>
<context>
    <name>QvkCiscoFinishDialog</name>
    <message>
        <source>The setup was successful.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Close this window and start vokoscreenNG again.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Have fun with vokoscreenNG</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>QvkDirectSoundController</name>
    <message>
        <source>Select one or more devices</source>
        <translation>Означи један или више уређаја</translation>
    </message>
</context>
<context>
    <name>QvkHelp</name>
    <message>
        <source>Help</source>
        <translation>Помоћ</translation>
    </message>
</context>
<context>
    <name>QvkImageFromTabs</name>
    <message>
        <source>No filemanager found.</source>
        <translation>Претраживач датотека није пронађен</translation>
    </message>
    <message>
        <source>Please install a filemanager.</source>
        <translation>Молим вас инсталирајте претраживач датотека</translation>
    </message>
</context>
<context>
    <name>QvkLimitDiskFreeSpace</name>
    <message>
        <source>Warning</source>
        <translation>Upozorenje</translation>
    </message>
    <message>
        <source>The recording is not started, not enough free disk space.</source>
        <translation>Снимање није почело, нема довољно слободног места на диску.</translation>
    </message>
    <message>
        <source>The free disk space limit is reached.</source>
        <translation>Досегнуто је ограничење слободног простора на диску.</translation>
    </message>
    <message>
        <source>Limit of free disk space</source>
        <translation>Граница слободног места на диску</translation>
    </message>
    <message>
        <source>Megabyte</source>
        <translation>Megabajt</translation>
    </message>
    <message>
        <source>The recording was stopped, not enough free disk space.</source>
        <translation>Снимање је заустављено, нема довољно слободног места на диску.</translation>
    </message>
</context>
<context>
    <name>QvkMainWindow</name>
    <message>
        <source>Fullscreen</source>
        <translation>Пун екран</translation>
    </message>
    <message>
        <source>Window</source>
        <translation>Прозор</translation>
    </message>
    <message>
        <source>No filemanager found.</source>
        <translation>Претраживач датотека није пронађен</translation>
    </message>
    <message>
        <source>Please install a filemanager.</source>
        <translation>Молим вас инсталирајте претраживач датотека</translation>
    </message>
    <message>
        <source>Sourcecode</source>
        <translation>Изворни код</translation>
    </message>
    <message>
        <source>Homepage</source>
        <translation>Почетна</translation>
    </message>
    <message>
        <source>Translations</source>
        <translation>Преводи</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>Донирај</translation>
    </message>
</context>
<context>
    <name>QvkPulseAudioWatcher</name>
    <message>
        <source>Select one or more devices</source>
        <translation>Означи један или више уређаја</translation>
    </message>
</context>
<context>
    <name>QvkRegionChoise</name>
    <message>
        <source>Area</source>
        <translation>Подручје</translation>
    </message>
</context>
<context>
    <name>QvkRegionChoise_wl</name>
    <message>
        <source>Area</source>
        <translation>Подручје</translation>
    </message>
</context>
<context>
    <name>QvkSystray</name>
    <message>
        <source>Start</source>
        <translation>Старт</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Стоп</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Пауза</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Настави</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Излаз</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Kamera</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>Увеличавање</translation>
    </message>
</context>
<context>
    <name>QvkSystrayAlternative</name>
    <message>
        <source>Start</source>
        <translation>Старт</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Стоп</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Пауза</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Настави</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Излаз</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Kamera</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>Увеличавање</translation>
    </message>
</context>
<context>
    <name>cameraSettingsDialog</name>
    <message>
        <source>Dialog</source>
        <translation>Дијалог</translation>
    </message>
    <message>
        <source>Flip horizontal</source>
        <translation>Окрени хоризонтално</translation>
    </message>
    <message>
        <source>Flip vertical</source>
        <translation>Окрени вертикално</translation>
    </message>
    <message>
        <source>Invert</source>
        <translation>Изокрени</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>Сиво</translation>
    </message>
    <message>
        <source>Black-and-white</source>
        <translation>Црно-бело</translation>
    </message>
    <message>
        <source>Remove window frame</source>
        <translation>Уклони оквир прозора</translation>
    </message>
    <message>
        <source>Camera settings</source>
        <translation>Подешавања камере</translation>
    </message>
</context>
<context>
    <name>formMainWindow</name>
    <message>
        <source>Area</source>
        <translation>Подручје</translation>
    </message>
    <message>
        <source>Reset</source>
        <translation>Поново намести</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>Увеличавање</translation>
    </message>
    <message>
        <source>Countdown</source>
        <translation>Одбројавање</translation>
    </message>
    <message>
        <source>Video size:</source>
        <translation>Величина видеа</translation>
    </message>
    <message>
        <source>Free disk space:</source>
        <translation>Слободан простор на диску</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>Информације</translation>
    </message>
    <message>
        <source>Record Time:</source>
        <translation>Сними време:</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation>Аудио</translation>
    </message>
    <message>
        <source>Frames</source>
        <translation>Фрејмови</translation>
    </message>
    <message>
        <source>Videocodec</source>
        <translation>Видео кодек</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>Формат</translation>
    </message>
    <message>
        <source>Audiocodec</source>
        <translation>Аудио кодек</translation>
    </message>
    <message>
        <source>Quality</source>
        <translation>Квалитет</translation>
    </message>
    <message>
        <source>Do not record mouse cursor</source>
        <translation>Немој снимати стрелицу</translation>
    </message>
    <message>
        <source>Hour</source>
        <translation>Сат</translation>
    </message>
    <message>
        <source>Minute</source>
        <translation>Минут</translation>
    </message>
    <message>
        <source>Start the timer</source>
        <translation>Покрени тајмер</translation>
    </message>
    <message>
        <source>Stop recording after</source>
        <translation>Прекини снимање после</translation>
    </message>
    <message>
        <source>Hours</source>
        <translation>Сати</translation>
    </message>
    <message>
        <source>Minutes</source>
        <translation>Минути</translation>
    </message>
    <message>
        <source>Seconds</source>
        <translation>Секунде</translation>
    </message>
    <message>
        <source>Videopath</source>
        <translation>Видео пут</translation>
    </message>
    <message>
        <source>Limit of free disk space</source>
        <translation>Граница слободног места на диску</translation>
    </message>
    <message>
        <source>Show in systray</source>
        <translation>Прикажи у &apos;&apos;systray&apos;&apos;</translation>
    </message>
    <message>
        <source>Second wait before recording</source>
        <translation>Одлагање снимања у секундама</translation>
    </message>
    <message>
        <source>Look for updates</source>
        <translation>Потражи исправке</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Помоћ</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>Снимак</translation>
    </message>
    <message>
        <source>Available</source>
        <translation>Доступно</translation>
    </message>
    <message>
        <source>Not available</source>
        <translation>Није доступно</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Старт</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Стоп</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Пауза</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Настави</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Почни</translation>
    </message>
    <message>
        <source>Folder</source>
        <translation>Фасцикла</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Kamera</translation>
    </message>
    <message>
        <source>Invert</source>
        <translation>Изокрени</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>Сиво</translation>
    </message>
    <message>
        <source>Send Report</source>
        <translation>Пошаљи извештај</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F10</source>
        <translation>CTRL+SHIFT+F10</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F11</source>
        <translation>CTRL+SHIFT+F11</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F12</source>
        <translation>CTRL+SHIFT+F12</translation>
    </message>
    <message>
        <source>Play last record</source>
        <translation>Пусти задњи снимак</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Отвори директоријум</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F8</source>
        <translation>CTRL+SHIFT+F8</translation>
    </message>
    <message>
        <source>Minimized when recording starts</source>
        <translation>Vokoscreen минимизиран кад снимање почне</translation>
    </message>
    <message>
        <source>Starts minimized</source>
        <translation>Почни минимизован</translation>
    </message>
    <message>
        <source>Flip horizontal</source>
        <translation>Окрени хоризонтално</translation>
    </message>
    <message>
        <source>Flip vertical</source>
        <translation>Окрени вертикално</translation>
    </message>
    <message>
        <source>Black-and-white</source>
        <translation>Црно-бело</translation>
    </message>
    <message>
        <source>Remove window frame</source>
        <translation>Уклони оквир прозора</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>Донирај</translation>
    </message>
    <message>
        <source>Reset all settings at the next start</source>
        <translation>Врати све на фабричка подешавања када следећи пут снимање почне </translation>
    </message>
    <message>
        <source>Copyright and license from pictures</source>
        <translation>Ауторска права и лиценца од слика</translation>
    </message>
    <message>
        <source>Megabyte</source>
        <translation>Megabajt</translation>
    </message>
    <message>
        <source>Screencast</source>
        <translation>Пренос екрана</translation>
    </message>
    <message>
        <source>Player</source>
        <translation>Плејер</translation>
    </message>
    <message>
        <source>Log</source>
        <translation>Дневник</translation>
    </message>
    <message>
        <source>Automatically</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Create images of tabs </source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>License information</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>ON</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>OFF</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Global keyboard shortcuts</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Assigned shortcut keys.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Keyboard shortcut not assigned or assigned more than once.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>If it shows assigned but does not work, it is being used by another program.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>license</name>
    <message>
        <source>Copyright and license from pictures</source>
        <translation>Ауторска права и лиценца од слика</translation>
    </message>
</context>
<context>
    <name>player</name>
    <message>
        <source>Play</source>
        <translation>Почни</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Пауза</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Стоп</translation>
    </message>
    <message>
        <source>Open File</source>
        <translation>Отвори документ</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Пун екран</translation>
    </message>
    <message>
        <source>Previous frame</source>
        <translation>Прошли кадар</translation>
    </message>
    <message>
        <source>Next frame</source>
        <translation>Следећи кадар</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>Нем</translation>
    </message>
    <message>
        <source>Move menu</source>
        <translation>Помери мени</translation>
    </message>
</context>
</TS>
